summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJürg Billeter <j@bitron.ch>2019-06-26 10:26:12 +0200
committerJürg Billeter <j@bitron.ch>2019-07-03 11:40:40 +0100
commitc66676efa109ac3caee9458a446ac775b58e7fc3 (patch)
tree24c2503b9f5c4b7f23cba1f2cab650ff9b333069
parent16d469dbee3c9667bf143ab85dfc0b80e178a099 (diff)
downloadbuildstream-c66676efa109ac3caee9458a446ac775b58e7fc3.tar.gz
element.py: Do not implicitly import sources into source cache
This should always be handled by Element._fetch().
-rw-r--r--src/buildstream/element.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/buildstream/element.py b/src/buildstream/element.py
index 835225b5e..fa4f63bff 100644
--- a/src/buildstream/element.py
+++ b/src/buildstream/element.py
@@ -1466,8 +1466,8 @@ class Element(Plugin):
# No workspace or cached buildtree, stage source from source cache
else:
- # Ensure sources are cached
- self.__cache_sources()
+ # Assert sources are cached
+ assert self._source_cached()
if self.__sources: